@@ -7,23 +7,7 @@
  ******************************************************************************
  * Copyright (c) 2023, Even Rouault <even dot rouault at spatialys.com>
  *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
- * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
- * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
+ * SPDX-License-Identifier: MIT
  ****************************************************************************/
 
 #include "cpl_port.h"
@@ -188,7 +172,9 @@ static struct archive *VSICreateArchiveHandle(const std::string &osFSPrefix)
     else
     {
         archive_read_support_format_rar(pArchive);
+#ifdef ARCHIVE_FORMAT_RAR_V5
         archive_read_support_format_rar5(pArchive);
+#endif
     }
 
     return pArchive;
@@ -394,13 +380,25 @@ class VSILibArchiveHandler final : public VSIVirtualHandle
         return 0;
     }
 
+    virtual void ClearErr() override
+    {
+        m_bEOF = false;
+        m_bError = false;
+    }
+
     virtual int Eof() override
     {
         return m_bEOF ? 1 : 0;
     }
 
+    virtual int Error() override
+    {
+        return m_bError ? 1 : 0;
+    }
+
     virtual int Close() override
     {
+        m_poReader.reset();
         return 0;
     }
 };
@@ -422,7 +420,12 @@ size_t VSILibArchiveHandler::Read(void *pBuffer, size_t nSize, size_t nCount)
     auto nRead = static_cast<size_t>(
         archive_read_data(m_poReader->GetArchiveHandler(), pBuffer, nToRead));
     if (nRead < nToRead)
-        m_bEOF = true;
+    {
+        if (m_nOffset + nRead == m_poReader->GetFileSize())
+            m_bEOF = true;
+        else
+            m_bError = true;
+    }
     m_nOffset += nRead;
     return nRead / nSize;
 }
@@ -523,7 +526,8 @@ class VSILibArchiveFilesystemHandler final : public VSIArchiveFilesystemHandler
 
 VSIVirtualHandle *VSILibArchiveFilesystemHandler::Open(const char *pszFilename,
                                                        const char *pszAccess,
-                                                       bool, CSLConstList)
+                                                       bool bSetError,
+                                                       CSLConstList)
 {
     if (strchr(pszAccess, 'w') != nullptr || strchr(pszAccess, '+') != nullptr)
     {
@@ -534,7 +538,7 @@ VSIVirtualHandle *VSILibArchiveFilesystemHandler::Open(const char *pszFilename,
 
     CPLString osFileInArchive;
     char *pszArchiveFileName =
-        SplitFilename(pszFilename, osFileInArchive, TRUE);
+        SplitFilename(pszFilename, osFileInArchive, true, bSetError);
     if (pszArchiveFileName == nullptr)
         return nullptr;
 
